document.addEventListener('DOMContentLoaded', function() {
  // Create simple visualizations in the placeholder divs
  const vizContainers = {
    pairplot: createDummyViz('Pairplot showing relationships between features'),
    boxplot: createDummyViz('Boxplot showing distribution of each feature'),
    heatmap: createDummyViz('Heatmap showing feature correlations')
  };
  
  Object.keys(vizContainers).forEach(id => {
    const container = document.getElementById(id);
    if (container) {
      container.innerHTML = vizContainers[id];
    }
  });
  
  // Add smooth scrolling for navigation links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function(e) {
      e.preventDefault();
      const targetId = this.getAttribute('href');
      const targetElement = document.querySelector(targetId);
      
      if (targetElement) {
        targetElement.scrollIntoView({
          behavior: 'smooth'
        });
      }
    });
  });
  
  // Add animation to stats cards on scroll
  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        entry.target.style.opacity = 1;
        entry.target.style.transform = 'translateY(0)';
      }
    });
  }, { threshold: 0.1 });
  
  document.querySelectorAll('.stat-card').forEach(card => {
    card.style.opacity = 0;
    card.style.transform = 'translateY(20px)';
    card.style.transition = 'opacity 0.5s ease, transform 0.5s ease';
    observer.observe(card);
  });
});

function createDummyViz(text) {
  const svg = `<svg viewBox="0 0 300 200" xmlns="http://www.w3.org/2000/svg">
    <rect width="100%" height="100%" fill="#f5f5f5" rx="8" ry="8"/>
    <text x="50%" y="50%" dominant-baseline="middle" text-anchor="middle" fill="#666" font-family="sans-serif">${text}</text>
  </svg>`;
  return svg;
}